==> zio-aws-ec2_2.12-5.17.161.1-sources.jar: zio/aws/ec2/model/DisableVpcClassicLinkRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.VpcId
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DisableVpcClassicLinkRequest(vpcId: VpcId) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DisableVpcClassicLinkRequest = {
    import DisableVpcClassicLinkRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DisableVpcClassicLinkRequest
      .builder()
      .vpcId(VpcId.unwrap(vpcId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.DisableVpcClassicLinkRequest.ReadOnly =
    zio.aws.ec2.model.DisableVpcClassicLinkRequest.wrap(buildAwsValue())
}
object DisableVpcClassicLinkRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DisableVpcClassicLinkRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DisableVpcClassicLinkRequest =
      zio.aws.ec2.model.DisableVpcClassicLinkRequest(vpcId)
    def vpcId: VpcId
    def getVpcId: ZIO[Any, Nothing, VpcId] = ZIO.succeed(vpcId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DisableVpcClassicLinkRequest
  ) extends zio.aws.ec2.model.DisableVpcClassicLinkRequest.ReadOnly {
    override val vpcId: VpcId = zio.aws.ec2.model.primitives.VpcId(impl.vpcId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DisableVpcClassicLinkRequest
  ): zio.aws.ec2.model.DisableVpcClassicLinkRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.12-7.21.15.12-sources.jar: zio/aws/ec2/model/DisableVpcClassicLinkRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.VpcId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DisableVpcClassicLinkRequest(
    dryRun: Optional[Boolean] = Optional.Absent,
    vpcId: VpcId
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DisableVpcClassicLinkRequest = {
    import DisableVpcClassicLinkRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DisableVpcClassicLinkRequest
      .builder()
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .vpcId(VpcId.unwrap(vpcId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.DisableVpcClassicLinkRequest.ReadOnly =
    zio.aws.ec2.model.DisableVpcClassicLinkRequest.wrap(buildAwsValue())
}
object DisableVpcClassicLinkRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DisableVpcClassicLinkRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DisableVpcClassicLinkRequest =
      zio.aws.ec2.model
        .DisableVpcClassicLinkRequest(dryRun.map(value => value), vpcId)
    def dryRun: Optional[Boolean]
    def vpcId: VpcId
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
    def getVpcId: ZIO[Any, Nothing, VpcId] = ZIO.succeed(vpcId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DisableVpcClassicLinkRequest
  ) extends zio.aws.ec2.model.DisableVpcClassicLinkRequest.ReadOnly {
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
    override val vpcId: VpcId = zio.aws.ec2.model.primitives.VpcId(impl.vpcId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DisableVpcClassicLinkRequest
  ): zio.aws.ec2.model.DisableVpcClassicLinkRequest.ReadOnly = new Wrapper(impl)
}
